### ===================================================================================================================
###                                                       VIIA
###                                                  Objectnr: XXXX
###                                            Structural engineer: Name
### ===================================================================================================================
# TEMPLATE MODELSCRIPT v4.3
# viiapackage version v##.#.#

# Copyright VIIA

# =====================================================================================================================
#                                                    INITIAL SETUP
# =====================================================================================================================

# Import the viiaPackage
from viiapackage import *

# Set up the project information
project = viia_create_project(project_name='XXXX', version_nr=1)

# =====================================================================================================================
#                                                     SETUP GRID
# =====================================================================================================================

# Create main orthogonal grid
grid = project.viia_create_orthogonal_grid([[0, 1.4, 2.5, 4.3], [0, 3.2, 5.0, 7.4]])

# Create the levels
project.viia_create_levels([-2.3, -1.7, -0.5, 0, 2.7, 5.0, 7.2])

# Plot the grid
project.viia_plot_grid(show=True)

# =====================================================================================================================
#                                                 LAYER B1 (BASEMENT)
# =====================================================================================================================
"""Step 4: Create Geometry"""

# Walls
b1_wall_list = [
    ['A1', 'A4', 'MW-KLEI<1945', 210],
    ['A4', 'D4', 'MW-KLEI<1945', 210],
    ['D4', 'D1', 'MW-KLEI<1945', 210],
    ['D1', 'A1', 'MW-KLEI<1945', 210]]
project.viia_create_walls_on_grid(layer='B1', z_bottom=grid['L2'], z_top=grid['L4'], wall_list=b1_wall_list)

# Columns
b1_column_list = [
    ['B2', grid['L2'], grid['L4'], 'LIN-STAAL', 'HEA180'],
    ['C2', grid['L2'], grid['L4'], 'LIN-STAAL', 'HEA180']]
project.viia_create_columns_on_grid(layer='B1', column_list=b1_column_list)

# =====================================================================================================================
#                                              LAYER N0 (GROUND FLOOR)
# =====================================================================================================================
"""Step 4: Create Geometry"""

# Walls
n0_wall_list = [
    ['A1', 'A4', 'MW-KLEI<1945', 100],
    ['A4', 'D4', 'MW-KLEI<1945', 100],
    ['D4', 'D1', 'MW-KLEI<1945', 100],
    ['D1', 'A1', 'MW-KLEI<1945', 100]]
project.viia_create_walls_on_grid(layer='N0', z_bottom=grid['L4'], z_top=grid['L5'], wall_list=n0_wall_list)

# Floors
n0_floor_list = [
    ['C1', 'C4', 'D4', 'D1', 'LIN-HBV-PLANKEN-0.018-0.07-0.17-0.6', 0],
    ['A1', 'A4', 'C4', 'C1', 'LIN-HBV-PLANKEN-0.018-0.07-0.17-0.6', 0, [0, 1, 0]]]  # Include local axis
project.viia_create_floors_on_grid(layer='N0', z_coordinate=grid['L4'], floor_list=n0_floor_list)

# Roofs

# Beams
n0_beam_list = [
    ['A2', 'C2', grid['L4'], 'STAAL-S235', 'IPE160'],
    ['C1', 'C4', grid['L4'], 'STAAL-S235', 'IPE200']]
project.viia_create_beams_on_grid(layer='N0', beam_list=n0_beam_list)

# Columns
n0_column_list = [
    ['A2', grid['L2'], grid['L4'], 'LIN-HOUT', '600x600']]
columns_n0 = project.viia_create_columns_on_grid(layer='N0', column_list=n0_column_list)

"""Step 5: Structural Schematisation"""

# Plot layer in 3D
# project.viia_plot_layers(layers='N0', view='3D')

# Plot with names of wall-shapes
# project.viia_plot_layers(layers='N0', view='2D', shape_types='walls')

"""Step 6: Edit Geometry"""

# Adding openings to surface shapes
n0_wall_opening_list = [
    ['wall_6', [[0.5, 1.0, 0.8, 0.8]], True],
    ['wall_7', [[1.0, 1.0, 0, 2.0], [1.0, 2.5, 0.3, 1.8]]]]
project.viia_add_openings(opening_data_list=n0_wall_opening_list)

# Create cavity walls and wall ties
project.viia_create_cavity_wall_ties_from_list(['wall_5', 'wall_6', 'wall_7', 'wall_8'], cavity=0.1)

# Create lintels
project.viia_create_all_lintels(lintel_material='LIN-STAAL', lintel_type='HEA100', collection='N0')

# =====================================================================================================================
#                                                      LAYER N1
# =====================================================================================================================
"""Step 4: Create Geometry"""

# Walls

# Floors
n1_floors = project.viia_create_floors_on_grid(
    layer='N1', z_coordinate=grid['L5'],
    floor_list=[['A1', 'A4', 'D4', 'D1', 'LIN-HBV-PLATEN-0.018-0.05-0.2-0.6', 0]])

# Roofs
roof_1 = project.viia_create_roof(
    name='N1', material='LIN-HBV-PLATEN-0.018-0.05-0.2-0.6', geometry=0,
    points=[[grid['A1', 'L5'], grid['A4', 'L5'], grid['C4', 'L6'], grid['C1', 'L6']]])
# Set the local x-axis to the inclined plane of the roof
roof_2 = project.viia_create_roof(
    name='N1', material='LIN-HBV-PLATEN-0.018-0.05-0.2-0.6', geometry=0,
    points=[[grid['C1', 'L6'], grid['C4', 'L6'], grid['D4', 'L5'], grid['D1', 'L5']]], element_x_axis='vertical')

# Columns
# Attach a column to the roof
project.viia_create_column(
    name='N1', material='LIN-STAAL', geometry='HEA140',
    points=[grid['B2', 'L5'], grid['B2'] + [roof_1]])

"""Step 5: Structural Schematisation"""

# Plot layer in 3D
# project.viia_plot_layers(layers='N1', view='3D')

# Plot with names of wall-shapes
# project.viia_plot_layers(layers='N1', view='2D', shape_types='walls')

"""Step 6: Edit Geometry"""

# =====================================================================================================================
#                                                      LAYER NX
# =====================================================================================================================
"""Step 4: Create Geometry"""

# Walls

# Floors

# Roofs

# Beams

# Columns

"""Step 5: Structural Schematisation"""

# Plot layer in 3D
# project.viia_plot_layers(layers='Nx', view='3D')

# Plot with names of wall-shapes
# project.viia_plot_layers(layers='Nx', view='2D', shape_types='walls')

"""Step 6: Edit Geometry"""

# =====================================================================================================================
#                                                     FOUNDATIONS
# =====================================================================================================================
"""Step 4: Create Geometry"""

walls = ['wall_1']
wall_ids = [1, 2, 3, 4]
walls_for_foundation = [project.viia_get('walls', id=wall_id) for wall_id in wall_ids]
project.viia_create_foundation_walls_and_strips(
    walls=walls_for_foundation,
    strip_material='LIN-MW-KLEI<1945',
    strip_width=400,
    strip_thickness=150,
    foundation_depth=grid['L1'])

# Columns
f_column_list = [
    ['A2', grid['L1'], grid['L2'], 'LIN-HOUT', '600x600']]
columns_f = project.viia_create_columns_on_grid(layer='F', column_list=f_column_list)

# =====================================================================================================================
#                                                  NON-SEISMIC LOADS
# =====================================================================================================================
"""Step 7: Apply non-seismic loads"""

# Permanent loads
# Create the self weight load-case
project.viia_create_loads('Self weight')

# Create the mass of all openings
project.viia_create_mass_all_openings()

# Load from interior wall 50kg/m (non-modelled walls)
project.viia_create_linemass(layer='N1', points=[grid['B2', 'L5'], grid['B4', 'L5']], value=50)

# Loads on sloped roofs
for roof in [roof_1, roof_2]:
    project.viia_create_surface_mass_floor(floor=roof, resting_load=['SlopeRoofLoad'])

# Imposed loads
# Loads on floors
loaded_floors = [floor for floor in project.collections.floors if floor.id in [1, 2]]
project.viia_create_loads(load='Imposed load', category='AFloor', connecting_shapes=loaded_floors)

# =====================================================================================================================
#                                                   FINALISE MODEL
# =====================================================================================================================
"""Step 7: Finalise the modelscript"""

# Connect all shapes
project.viia_connect_all_shapes()

# Set data properties to all shapes
project.viia_create_all_datas()

# View model in matplot
# project.viia_create_plots()

# Create json-file from model (stored in model sub-folder)
project.viia_write_dump()

# Create pictures for building structural setup appendix
project.viia_create_model_plots()

# Create the building structural setup appendix
project.viia_create_model_plots_appendix()

# =====================================================================================================================
#                                                 END OF MODELSCRIPT
# =====================================================================================================================
